@@ -345,6 +345,7 @@ class K8SCaller(object):
         volumeMounts=None,
         envFrom=None,
         entrypoint=None,
+        privileged=False,
         **kw,
     ):
         url, version = POST_OPS["job"]
@@ -362,7 +363,8 @@ class K8SCaller(object):
             volumeMounts=volumeMounts,
             envFrom=envFrom,
             entrypoint=entrypoint,
-            **kw,
+            privileged=privileged,
+            **kw
         )
         return await self.post(url, version, obj.payload())
 
